//! Program accounts

pub mod enums;
pub mod governance;
pub mod legacy;
pub mod native_treasury;
pub mod program_metadata;
pub mod proposal;
pub mod proposal_transaction;
pub mod realm;
pub mod realm_config;
pub mod signatory_record;
pub mod token_owner_record;
pub mod vote_record;
